@@ -27,7 +27,7 @@ Project link:
     https://github.com/funilrys/PyFunceble
 
 Project documentation:
-    https://pyfunceble.readthedocs.io/en/dev/
+    https://docs.pyfunceble.com
 
 Project homepage:
     https://pyfunceble.github.io/
@@ -410,8 +410,8 @@ class SystemLauncher(SystemBase):
 
         # pylint: disable=line-too-long
         if (
-            not self.testing_protocol and
-            PyFunceble.storage.CONFIGURATION.cli_testing.testing_mode.platform_contribution
+            not self.testing_protocol
+            and PyFunceble.storage.CONFIGURATION.cli_testing.testing_mode.platform_contribution
         ):
             self.testing_protocol.append(
                 {
@@ -507,7 +507,9 @@ class SystemLauncher(SystemBase):
                 possible_session_id = running_file_helper.read().split()[0]
 
                 try:
-                    _ = datetime.datetime.fromisoformat(possible_session_id)
+                    _ = datetime.datetime.fromisoformat(possible_session_id).astimezone(
+                        datetime.timezone.utc
+                    )
                     self.sessions_id[parent_dirname] = None
                 except (ValueError, TypeError):
                     self.sessions_id[parent_dirname] = possible_session_id
